--
-- 
-- @Author: Kim Brandwijk / Derelky
-- @Version: 1.0.0.0
--

--


GC_AnimalSeasonsFix = {}
GC_AnimalSeasonsFix.SHOW_WARNING = false

function GC_AnimalSeasonsFix:initGlobalCompany(customEnvironment, baseDirectory, xmlFile)
    if (g_company == nil) or (g_company.animalSeasonsFixAddon ~= nil) then
        return
    end

    if g_company.animalLoadingTrigger ~= nil then
        
        -- Only load once even if added to multiple mods or in the map also.
        g_company.animalSeasonsFixAddon = GC_AnimalSeasonsFix
        g_company.animalLoadingTrigger.deliverAnimals = Utils.overwrittenFunction(g_company.animalLoadingTrigger.deliverAnimals, GC_AnimalSeasonsFix.deliverAnimals)

        -- No need to register this script to 'debug' so I will just print a header and info text.
        g_company.debug:printHeader({header = "  [LSMC - GlobalCompany] - [GC_AnimalSeasonsFix]"})
        g_company.debug:print("    INFORMATION: Initialized GC_AnimalSeasonsFix.")
    end
end

function GC_AnimalSeasonsFix:deliverAnimals(superFunc, animalTrailer, numberToDeliver)
	if not self.isServer or animalTrailer == nil then
        return
    end

	local animals = animalTrailer:getAnimals()
    local numAnimal = #animals
    local difficultyFactor = EconomyManager.getPriceMultiplier()
	
	if numAnimal > 0 then
        local typeName = animalTrailer:getCurrentAnimalType()
        
		if self:getAnimalTypeAccepted(typeName) then
			local subType = animals[1]:getSubType()
			local fillTypeIndex = subType.fillType
			if fillTypeIndex ~= nil then
				local farmId = animalTrailer:getOwnerFarmId()

                local litresPerAnimal = self:getConversionDataPerAnimal(typeName)

				local freeCapacity = self:getFreeCapacity(typeName, subType, farmId)
				local maxAvailableAnimals = math.min(numberToDeliver, numAnimal)
				local numberToRemove = math.min(maxAvailableAnimals, freeCapacity)
	
				for i = numberToRemove, 1 , -1 do
                    if g_seasons then
						seasonsvalue = animals[i]:getValue()
                        litresPerAnimal = seasonsvalue
                    end
					litresPerAnimal = litresPerAnimal/difficultyFactor
                    animalTrailer:removeAnimals({animals[i]})
                    self.target:addFillLevel(farmId, litresPerAnimal, fillTypeIndex, ToolType.UNDEFINED, nil, self.extraParamater)
				end
			end
		end
	end
end
